<?php

use EventPortal\Domain\Agenda\Handlers\AssociateToPathway;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Agenda\Rules\NoOverlap;
use EventPortal\Domain\Component\Dropdown\MultiSelect;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Input\TextArea;
use EventPortal\Domain\Component\Input\TimeInput;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventSpeaker;
use EventPortal\Domain\Event\Models\EventVenue;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Domain\Handlers\UpdateModel;

$fields = function (Pathway $pathway, Event $event) {
    return [
        Section::make()->fields([
            Text::make('Session Name')
                ->name('name')
                ->alternativeName('session-name')
                ->placeholder('Lunch break')
                ->rules(['required', 'max:255']),
            TextArea::make('Session Description')
                ->name('description')
                ->alternativeName('session-description')
                ->placeholder('Description of session')
                ->rules(['nullable', 'max:255']),
            TimeInput::make('Start time')
                ->name('starting_at')
                ->alternativeName('session-start-time')
                ->rules(['required', 'before:ending_at', new NoOverlap($pathway)]),
            TimeInput::make('End time')
                ->name('ending_at')
                ->alternativeName('session-end-time')
                ->rules(['required', 'after:starting_at', new NoOverlap($pathway)]),
            Text::make('Add a location')
                ->name('location')
                ->alternativeName('session-location')
                ->placeholder('Canteen')
                ->rules(['required', 'max:255']),
            MultiSelect::make('Speaker')
                ->name('speakers')
                ->alternativeName('session-speakers')
                ->options(EventSpeaker::forEvent($event)->get()->map(function (EventSpeaker $eventSpeaker) {
                    return $eventSpeaker->asOption();
                })->toArray()),
            Select::make('Venue')
                ->placeholder('Select a venue')
                ->name('event_venue_id')
                ->alternativeName('session-venue')
                ->options(EventVenue::forEvent($event)->get()->map(function (EventVenue $eventVenue) {
                    return $eventVenue->asOption();
                })->toArray()),
        ]),
    ];
};

Form::make('session.create')
    ->addHandler(new CreateModel)
    ->addHandler(new AssociateToPathway)
    ->addFields($fields);

Form::make('session.update')
    ->addHandler(new UpdateModel)
    ->addFields($fields);
