<?php

namespace EventPortal\Domain\Util;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Collection;

class Parameters
{
    /** @var Collection */
    private $parameters;

    public function __construct(array $parameters)
    {
        $this->parameters = collect($parameters);
    }

    public static function make(array $parameters): self
    {
        return new static($parameters);
    }

    /**
     * If parameters have a Model, return its key.
     */
    public function asPlain(): self
    {
        $this->parameters = $this
            ->parameters
            ->mapWithKeys(function ($value, $key) {
                if ($value instanceof Model) {
                    return [$key => $value->getKey()];
                }

                return [$key => $value];
            });

        return $this;
    }

    public function get(): Collection
    {
        return $this->parameters;
    }

    public function asArray(): array
    {
        return $this->parameters->toArray();
    }
}
