<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class PathwayTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_for_agenda()
    {
        $agenda = factory(Agenda::class)->create();

        $pathway = Pathway::generate(
            $agenda,
            'Default Pathway',
            'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In eget quam enim.'
        );

        $this
            ->assertHasPathway($agenda, $pathway)
            ->assertDatabaseHas('pathways', [
                'name' => 'Default Pathway',
                'description' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In eget quam enim.',
            ]);
    }

    /** @test **/
    public function can_create_for_form(): void
    {
        $form = factory(Form::class)->create();

        $pathway = Pathway::generate(
            $form,
            'Default Pathway',
            'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In eget quam enim.'
        );

        $this
            ->assertHasPathway($form, $pathway)
            ->assertDatabaseHas('pathways', [
                'name' => 'Default Pathway',
                'description' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In eget quam enim.',
            ]);
    }
}
