<?php

namespace EventPortal\Tests\Unit\Agenda\Requests;

use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Requests\StoreAgendaRequest;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Validator;

class StoreAgendaRequestTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function date_must_be_unique()
    {
        $agenda = factory(Agenda::class)->create(['date' => '2020-07-15']);

        $request = (new StoreAgendaRequest())->merge(['event' => $agenda->event]);

        $validator = Validator::make(
            ['dates' => ['2020-07-15']],
            $request->rules()
        );

        $this->assertFalse($validator->passes());
    }

    /** @test **/
    public function date_must_be_unique_for_event()
    {
        $agendaA = factory(Agenda::class)->create(['date' => '2020-07-15']);
        $agendaB = factory(Agenda::class)->create(['date' => '2020-07-16']);

        $request = (new StoreAgendaRequest())->merge(['event' => $agendaB->event]);

        $validator = Validator::make(
            ['dates' => ['2020-07-15']],
            $request->rules()
        );

        $this->assertTrue($validator->passes());
    }
}
