<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Util\Menu\Facades\Menu;
use EventPortal\Domain\Util\Menu\Link;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class MenuTest extends TestCase
{
    use MatchesSnapshots, RefreshDatabase;

    /** @test */
    public function can_add_links()
    {
        $event = factory(Event::class)->create(['name' => 'Test Event', 'slug' => 'test-event']);

        $menu = Menu::make('test')
            ->addLinks(function (Event $event) {
                return [
                    Link::make('Home')
                        ->route('delegate.landing', [
                            'event' => $event->slug,
                        ]),
                ];
            })
            ->context($event)
            ->get();

        $this->assertMatchesJsonSnapshot($menu);
    }

    /** @test */
    public function can_add_buttons()
    {
        $event = factory(Event::class)->create(['name' => 'Test Event', 'slug' => 'test-event']);

        $menu = Menu::make('test')
            ->addButtons(function () {
                return [
                    Button::make('Sign out')
                        ->method(InertiaMethod::POST())
                        ->route('logout.submit')
                        ->variant('secondary')
                        ->icon('logout', 'right'),
                ];
            })
            ->context($event)
            ->get();

        $this->assertMatchesJsonSnapshot($menu);
    }

    /** @test */
    public function can_hide_link()
    {
        $event = factory(Event::class)->create(['name' => 'Test Event', 'slug' => 'test-event']);

        $menu = Menu::make('test')
            ->context($event)
            ->addLinks(function () {
                return [
                    Link::make('Something else')->canSee(false),
                ];
            })
            ->get();

        $this->assertMatchesJsonSnapshot($menu);
    }

    /** @test */
    public function can_hide_link_callable()
    {
        $event = factory(Event::class)->create(['name' => 'Test Event', 'slug' => 'test-event']);

        $menu = Menu::make('test')
            ->context($event)
            ->addLinks(function () {
                return [
                    Link::make('Something else')
                        ->canSee(function () {
                            return false;
                        }),
                ];
            })
            ->get();

        $this->assertMatchesJsonSnapshot($menu);
    }
}
